@@ -44,20 +44,24 @@ module GLib
       Lib.g_array_get_element_size self
     end
 
-    alias element_size get_element_size
+    alias_method :element_size, :get_element_size
 
     def == other
       to_a == other.to_a
     end
 
-    def reset_typespec typespec
-      @element_type = typespec
-      check_element_size_match
+    def reset_typespec typespec = nil
+      if typespec
+        @element_type = typespec
+        check_element_size_match
+      else
+        @element_type = guess_element_type
+      end
       self
     end
 
     def self.from_enumerable elmtype, it
-      new(elmtype).tap {|arr| arr.append_vals it }
+      new(elmtype).tap { |arr| arr.append_vals it }
     end
 
     private
@@ -76,5 +80,14 @@ module GLib
         warn "WARNING: Element sizes do not match"
       end
     end
+
+    def guess_element_type
+      case get_element_size
+      when 1 then :uint8
+      when 2 then :uint16
+      when 4 then :uint32
+      when 8 then :uint64
+      end
+    end
   end
 end
