@@ -10,10 +10,10 @@ module GLib
     end
 
     def self.constructor_wrap ptr
-      super.tap {|variant| variant.ref }
+      super.tap(&:ref)
     end
 
-    alias get_string_without_override get_string
-    alias get_string get_string_with_override
+    alias_method :get_string_without_override, :get_string
+    alias_method :get_string, :get_string_with_override
   end
 end
