@@ -15,22 +15,6 @@ require 'gir_ffi/builders/user_defined_builder'
 
 # Module representing GLib's GObject namespace.
 module GObject
-  def self.object_ref obj
-    Lib.g_object_ref obj.to_ptr
-  end
-
-  def self.object_ref_sink obj
-    Lib.g_object_ref_sink obj.to_ptr
-  end
-
-  def self.object_unref obj
-    Lib.g_object_unref obj.to_ptr
-  end
-
-  def self.object_is_floating obj
-    Lib.g_object_is_floating obj.to_ptr
-  end
-
   def self.type_from_instance_pointer inst_ptr
     return nil if inst_ptr.null?
     klsptr = inst_ptr.get_pointer 0
@@ -70,12 +54,12 @@ module GObject
     return_gvalue
   end
 
-  def self.signal_connect object, detailed_signal, data=nil, &block
+  def self.signal_connect object, detailed_signal, data = nil, &block
     raise ArgumentError, "Block needed" unless block_given?
     signal_name, _ = detailed_signal.split('::')
     sig_info = object.class.find_signal signal_name
 
-    closure = sig_info.wrap_in_closure {|*args| block.call(*args << data) }
+    closure = sig_info.wrap_in_closure { |*args| block.call(*args << data) }
 
     # TODO: Provide _after variant
     signal_connect_closure object, detailed_signal, closure, false
@@ -96,12 +80,10 @@ module GObject
 
   # NOTE: This Lib module is set up in `gir_ffi-base/gobject/lib.rb`.
   module Lib
-    attach_function :g_object_ref, [:pointer], :void
     attach_function :g_object_ref_sink, [:pointer], :void
-    attach_function :g_object_unref, [:pointer], :void
-    attach_function :g_object_is_floating, [:pointer], :bool
 
     attach_function :g_array_get_type, [], :size_t
+    attach_function :g_byte_array_get_type, [], :size_t
     attach_function :g_hash_table_get_type, [], :size_t
     attach_function :g_strv_get_type, [], :size_t
 
@@ -117,6 +99,7 @@ module GObject
   end
 
   TYPE_ARRAY = Lib.g_array_get_type
+  TYPE_BYTE_ARRAY = Lib.g_byte_array_get_type
   TYPE_HASH_TABLE = Lib.g_hash_table_get_type
   TYPE_STRV = Lib.g_strv_get_type
 end
