@@ -32,16 +32,17 @@ module GObject
 
       closure = wrap(new_simple(self::Struct.size, nil).to_ptr)
       closure.block = block
-      closure.set_marshal Proc.new {|*args| marshaller(*args)}
+      closure.set_marshal proc { |*args| marshaller(*args) }
 
       closure
     end
 
     def self.marshaller closure, return_value, param_values, _invocation_hint, _marshal_data
+      # TODO: Improve by registering RubyClosure as a GObject type
       rclosure = wrap(closure.to_ptr)
       param_values ||= []
 
-      args = param_values.map {|value| value.get_value }
+      args = param_values.map(&:get_value)
 
       result = rclosure.invoke_block(*args)
 
