@@ -20,7 +20,7 @@ module GirFFI
       def fetch ptr
         return if ptr.null?
         key = ptr.address
-        if @store.has_key? key
+        if @store.key? key
           @store[key]
         else
           ptr
@@ -74,7 +74,7 @@ module GirFFI
 
     def self.cast_uint32_to_int32 val
       if val >= 0x80000000
-        -(0x100000000-val)
+        -(0x100000000 - val)
       else
         val
       end
