@@ -9,37 +9,39 @@ module GirFFI
     # Implements building pre- and post-processing statements for arguments.
     class ArgumentBuilder < BaseArgumentBuilder
       def method_argument_name
-        if has_input_value? && !is_array_length_parameter?
-          name
-        end
+        name if has_input_value? && !array_length_parameter?
       end
 
       def post_converted_name
         @post_converted_name ||= if has_post_conversion?
                                    new_variable
                                  else
-                                   callarg
+                                   call_argument_name
                                  end
       end
 
       def return_value_name
         if has_output_value?
-          post_converted_name unless is_array_length_parameter?
+          post_converted_name unless array_length_parameter?
         end
       end
 
+      def capture_variable_name
+        nil
+      end
+
       def pre_conversion
         pr = []
         case direction
         when :in
           pr << fixed_array_size_check if needs_size_check?
-          pr << array_length_assignment if is_array_length_parameter?
-          pr << "#{callarg} = #{ingoing_convertor.conversion}"
+          pr << array_length_assignment if array_length_parameter?
+          pr << "#{call_argument_name} = #{ingoing_convertor.conversion}"
         when :inout
           pr << fixed_array_size_check if needs_size_check?
-          pr << array_length_assignment if is_array_length_parameter?
+          pr << array_length_assignment if array_length_parameter?
           pr << out_parameter_preparation
-          pr << "#{callarg}.set_value #{ingoing_convertor.conversion}"
+          pr << "#{call_argument_name}.set_value #{ingoing_convertor.conversion}"
         when :out
           pr << out_parameter_preparation
         end
@@ -58,11 +60,11 @@ module GirFFI
       private
 
       def has_post_conversion?
-        has_output_value? && !is_caller_allocated_object?
+        has_output_value? && !caller_allocated_object?
       end
 
       def output_value
-        base = "#{callarg}.to_value"
+        base = "#{call_argument_name}.to_value"
         if needs_out_conversion?
           CToRubyConvertor.new(@type_info, base, length_argument_name).conversion
         elsif allocated_by_them?
@@ -88,7 +90,7 @@ module GirFFI
         length_arg && length_arg.post_converted_name
       end
 
-      def is_array_length_parameter?
+      def array_length_parameter?
         @array_arg
       end
 
@@ -120,7 +122,7 @@ module GirFFI
       end
 
       def out_parameter_preparation
-        value = if is_caller_allocated_object?
+        value = if caller_allocated_object?
                   if specialized_type_tag == :array
                     "#{argument_class_name}.new #{type_info.element_type.inspect}"
                   else
@@ -129,18 +131,18 @@ module GirFFI
                 else
                   "GirFFI::InOutPointer.for #{type_info.tag_or_class.inspect}"
                 end
-        "#{callarg} = #{value}"
+        "#{call_argument_name} = #{value}"
       end
 
-      def is_caller_allocated_object?
-        [ :struct, :array ].include?(specialized_type_tag) &&
+      def caller_allocated_object?
+        [:struct, :array].include?(specialized_type_tag) &&
           @arginfo.caller_allocates?
       end
 
       def ingoing_convertor
         if skipped?
           NullConvertor.new("0")
-        elsif is_closure
+        elsif closure?
           ClosureToPointerConvertor.new(name)
         elsif @type_info.needs_ruby_to_c_conversion_for_functions?
           RubyToCConvertor.new(@type_info, name)
