@@ -4,17 +4,27 @@ module GirFFI
     # classes are used by FunctionBuilder to create the code that
     # processes each argument before and after the actual function call.
     class BaseArgumentBuilder
-      KEYWORDS = [
-        "alias", "and", "begin", "break", "case", "class", "def", "do",
-        "else", "elsif", "end", "ensure", "false", "for", "if", "in",
-        "module", "next", "nil", "not", "or", "redo", "rescue", "retry",
-        "return", "self", "super", "then", "true", "undef", "unless",
-        "until", "when", "while", "yield"
-      ]
+      KEYWORDS = %w(
+        alias and begin break case class def do
+        else elsif end ensure false for if in
+        module next nil not or redo rescue retry
+        return self super then true undef unless
+        until when while yield
+      )
 
       attr_reader :arginfo
       attr_accessor :length_arg, :array_arg
-      attr_accessor :is_closure
+
+      # TODO: closure unfortunately means two things in GLib: a closure
+      # argument (user_data), and the Closure class (a callable object). Make
+      # the distinction more explicit in GirFFI.
+      def closure?
+        @is_closure
+      end
+
+      def closure= arg
+        @is_closure = arg
+      end
 
       def initialize var_gen, arginfo
         @var_gen = var_gen
@@ -58,8 +68,8 @@ module GirFFI
         end
       end
 
-      def callarg
-        @callarg ||= new_variable
+      def call_argument_name
+        @call_argument_name ||= new_variable
       end
 
       def new_variable
