@@ -9,18 +9,24 @@ module GirFFI
     class ObjectBuilder < RegisteredTypeBuilder
       include WithLayout
 
-      def find_signal signal_name
-        signal_definers.each do |inf|
-          sig = inf.find_signal signal_name
-          return sig if sig
+      # Dummy builder for the ObjectBase class
+      class ObjectBaseBuilder
+        def build_class
+          ObjectBase
         end
-        superclass.find_signal signal_name or
+
+        def ancestor_infos
+          []
+        end
+      end
+
+      def find_signal signal_name
+        seek_in_ancestor_infos { |info| info.find_signal signal_name } or
           raise "Signal #{signal_name} not found"
       end
 
       def find_property property_name
-        info.find_property property_name or
-          superclass.find_property property_name or
+        seek_in_ancestor_infos { |info| info.find_property property_name } or
           raise "Property #{property_name} not found"
       end
 
@@ -28,6 +34,10 @@ module GirFFI
         @object_class_struct ||= Builder.build_class object_class_struct_info
       end
 
+      def ancestor_infos
+        @ancestor_infos ||= [info] + info.interfaces + parent_ancestor_infos
+      end
+
       private
 
       def setup_class
@@ -48,24 +58,29 @@ module GirFFI
         FFI::Struct
       end
 
-      def parent
-        unless defined? @parent
-          pr = info.parent
-          if pr.nil? or (pr.safe_name == @classname and pr.namespace == @namespace)
-            @parent = nil
-          else
-            @parent = pr
-          end
+      def parent_info
+        unless defined? @parent_info
+          @parent_info = if (parent = info.parent) && parent != info
+                           parent
+                         end
         end
-        @parent
+        @parent_info
       end
 
       def superclass
-        @superclass ||= if parent
-                          Builder.build_class parent
-                        else
-                          ObjectBase
-                        end
+        @superclass ||= parent_builder.build_class
+      end
+
+      def parent_builder
+        @parent_builder ||= if parent_info
+                              Builders::TypeBuilder.builder_for(parent_info)
+                            else
+                              ObjectBaseBuilder.new
+                            end
+      end
+
+      def parent_ancestor_infos
+        @parent_ancestor_infos ||= parent_builder.ancestor_infos
       end
 
       def setup_property_accessors
@@ -99,10 +114,6 @@ module GirFFI
         end
       end
 
-      def signal_definers
-        [info] + info.interfaces
-      end
-
       def interfaces
         info.interfaces.map do |ifinfo|
           GirFFI::Builder.build_class ifinfo
@@ -112,6 +123,14 @@ module GirFFI
       def object_class_struct_info
         @object_class_struct_info ||= info.class_struct
       end
+
+      def seek_in_ancestor_infos
+        ancestor_infos.each do |info|
+          item = yield info
+          return item if item
+        end
+        nil
+      end
     end
   end
 end
