@@ -23,6 +23,7 @@ module GirFFI
         container_class.class_eval setter_def
       end
 
+      # TODO: Fix argument builders so converting_getter_def can always be used.
       def getter_def
         case type_info.tag
         when :glist, :ghash
@@ -32,6 +33,7 @@ module GirFFI
         end
       end
 
+      # TODO: Fix argument builders so converting_setter_def can always be used.
       def setter_def
         case type_info.flattened_tag
         when :glist, :ghash, :strv
@@ -43,10 +45,12 @@ module GirFFI
 
       private
 
+      # TODO: Use a builder like MarshallingMethodBuilder
       def converting_getter_def
+        capture = getter_builder.capture_variable_name
         <<-CODE.reset_indentation
         def #{getter_name}
-          #{getter_builder.capture_variable_name} = get_property("#{property_name}").get_value_plain
+          #{capture} = get_property("#{property_name}").get_value_plain
           #{getter_builder.post_conversion.join("\n")}
           #{getter_builder.return_value_name}
         end
@@ -70,7 +74,7 @@ module GirFFI
         <<-CODE.reset_indentation
         def #{setter_name} value
           #{setter_builder.pre_conversion.join("\n")}
-          set_property("#{property_name}", #{setter_builder.callarg})
+          set_property("#{property_name}", #{setter_builder.call_argument_name})
         end
         CODE
       end
