@@ -9,37 +9,33 @@ module GirFFI
         @info = info
       end
 
-      def instantiate_class
-        if already_set_up
-          @gtype = klass.get_gtype
-        else
-          @gtype = GObject.type_register_static(parent_gtype.to_i,
-                                                info.g_name,
-                                                gobject_type_info, 0)
-          included_interfaces.each do |interface|
-            ifinfo = gobject_interface_info interface
-            GObject.type_add_interface_static @gtype, interface.get_gtype, ifinfo
-          end
-          setup_class
-          TypeBuilder::CACHE[@gtype] = klass
-        end
-      end
-
       def setup_class
+        register_type
         setup_layout
         setup_constants
         setup_property_accessors
         setup_constructor
+        TypeBuilder::CACHE[@gtype] = klass
       end
 
       def target_gtype
-        @gtype
+        @gtype ||= klass.get_gtype
       end
 
       private
 
-      def parent
-        @parent ||= gir.find_by_gtype(parent_gtype.to_i)
+      def register_type
+        @gtype = GObject.type_register_static(parent_gtype.to_i,
+                                              info.g_name,
+                                              gobject_type_info, 0)
+        included_interfaces.each do |interface|
+          ifinfo = gobject_interface_info interface
+          GObject.type_add_interface_static @gtype, interface.get_gtype, ifinfo
+        end
+      end
+
+      def parent_info
+        @parent_info ||= gir.find_by_gtype(parent_gtype.to_i)
       end
 
       def parent_gtype
@@ -47,7 +43,7 @@ module GirFFI
       end
 
       def interface_gtypes
-        included_interfaces.map {|interface| GType.new(interface.get_gtype) }
+        included_interfaces.map { |interface| GType.new(interface.get_gtype) }
       end
 
       def included_interfaces
@@ -121,7 +117,8 @@ module GirFFI
       end
 
       def setup_vfuncs object_class_ptr
-        super_class_struct = superclass.gir_ffi_builder.object_class_struct::Struct.new(object_class_ptr)
+        super_class_struct =
+          superclass.gir_ffi_builder.object_class_struct::Struct.new(object_class_ptr)
 
         info.vfunc_implementations.each do |impl|
           setup_vfunc super_class_struct, impl
@@ -141,7 +138,7 @@ module GirFFI
 
       def setup_vfunc super_class_struct, impl
         vfunc_name = impl.name
-        vfunc_info = parent.find_vfunc vfunc_name.to_s
+        vfunc_info = parent_info.find_vfunc vfunc_name.to_s
 
         if vfunc_info
           install_vfunc super_class_struct, vfunc_name, vfunc_info, impl.implementation
