@@ -1,5 +1,4 @@
 require 'forwardable'
-require 'gir_ffi/builders/null_builder'
 require 'gir_ffi/registered_type_base'
 
 module GirFFI
@@ -12,13 +11,11 @@ module GirFFI
     attr_reader :struct
     def_delegators :@struct, :to_ptr
 
-    GIR_FFI_BUILDER = NullBuilder.new
-
-    def setup_and_call method, *arguments, &block
+    def setup_and_call method, arguments, &block
       method_name = self.class.try_in_ancestors(:setup_instance_method, method.to_s)
 
       unless method_name
-        raise RuntimeError, "Unable to set up instance method '#{method}' in #{self}"
+        raise "Unable to set up instance method '#{method}' in #{self}"
       end
 
       send method_name, *arguments, &block
@@ -30,11 +27,11 @@ module GirFFI
       other.class == self.class && to_ptr.address == other.to_ptr.address
     end
 
-    def self.setup_and_call method, *arguments, &block
+    def self.setup_and_call method, arguments, &block
       method_name = try_in_ancestors(:setup_method, method.to_s)
 
       unless method_name
-        raise RuntimeError, "Unable to set up method '#{method}' in #{self}"
+        raise "Unable to set up method '#{method}' in #{self}"
       end
 
       send method_name, *arguments, &block
@@ -74,9 +71,9 @@ module GirFFI
       # Wrap the passed pointer in an instance of the current class. Will not
       # do any casting to subtypes.
       def direct_wrap ptr
-        return nil if !ptr or ptr.null?
+        return nil if !ptr || ptr.null?
         obj = _real_new
-        obj.instance_variable_set :@struct, self::Struct.new(ptr.to_ptr)
+        obj.instance_variable_set :@struct, self::Struct.new(ptr)
         obj
       end
 
