@@ -38,11 +38,11 @@ module GirFFI
       from_native pointer.get_int32(0), nil
     end
 
-    def setup_and_call method, *arguments, &block
+    def setup_and_call method, arguments, &block
       result = setup_method method.to_s
 
       unless result
-        raise RuntimeError, "Unable to set up method #{method} in #{self}"
+        raise "Unable to set up method #{method} in #{self}"
       end
 
       send method, *arguments, &block
