@@ -3,9 +3,7 @@ module GirFFI
     # Extensions for GObjectIntrospection::IFieldInfo needed by GirFFI
     module IFieldInfo
       def layout_specification
-        [ name.to_sym,
-          field_type.to_ffitype,
-          offset ]
+        [name.to_sym, field_type.to_ffitype, offset]
       end
     end
   end
