@@ -20,4 +20,5 @@ module GirFFI
   end
 end
 
-GObjectIntrospection::IRegisteredTypeInfo.send :include, GirFFI::InfoExt::IRegisteredTypeInfo
+GObjectIntrospection::IRegisteredTypeInfo.send :include,
+  GirFFI::InfoExt::IRegisteredTypeInfo
