@@ -11,14 +11,15 @@ module GirFFI
       load_class(classname) || super
     end
 
+    # @deprecated The load_class method should always be used. Remove in 0.8.0
     def setup_class classname
       gir_ffi_builder.build_namespaced_class classname.to_s
     end
 
-    alias load_class setup_class
+    alias_method :load_class, :setup_class
 
     def gir_ffi_builder
-      const_get :GIR_FFI_BUILDER
+      self::GIR_FFI_BUILDER
     end
 
     def setup_method name
