@@ -200,7 +200,7 @@ describe GObject::Value do
 
     it "works with a ByteArray" do
       ba = GLib::ByteArray.new.append("some bytes")
-      v = GObject::Value.for_g_type GObject.type_from_name("GByteArray")
+      v = GObject::Value.for_g_type GObject::TYPE_BYTE_ARRAY
       v.set_boxed ba
 
       result = v.get_value
@@ -208,6 +208,17 @@ describe GObject::Value do
       result.to_string.must_equal "some bytes"
       result.must_be_kind_of GLib::ByteArray
     end
+
+    it "works with an Array" do
+      arr = GLib::Array.from(:uint, [1, 2, 3])
+      v = GObject::Value.for_g_type GObject::TYPE_ARRAY
+      v.set_boxed arr
+
+      result = v.get_value
+
+      result.must_be_kind_of GLib::Array
+      result.reset_typespec(:uint).to_a.must_equal [1, 2, 3]
+    end
   end
 
   describe "::from" do
