@@ -8,7 +8,7 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def self.test_array_fixed_out_objects 
+      def self.test_array_fixed_out_objects
         _v1 = GirFFI::InOutPointer.for [:pointer, :c]
         Regress::Lib.regress_test_array_fixed_out_objects _v1
         _v2 = GirFFI::SizedArray.wrap([:pointer, Regress::TestObj], 2, _v1.to_value)
@@ -25,7 +25,7 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def self.test_array_gint16_in ints
+      def self.test_array_gint16_in(ints)
         n_ints = ints.nil? ? 0 : ints.length
         _v1 = n_ints
         _v2 = GirFFI::SizedArray.from(:gint16, -1, ints)
@@ -43,7 +43,7 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def self.test_callback_destroy_notify callback, user_data, notify
+      def self.test_callback_destroy_notify(callback, user_data, notify)
         _v1 = Regress::TestCallbackUserData.from(callback)
         _v2 = GirFFI::InPointer.from_closure_data(user_data)
         _v3 = GLib::DestroyNotify.from(notify)
@@ -61,7 +61,7 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def self.new_from_file x
+      def self.new_from_file(x)
         _v1 = GirFFI::InPointer.from(:utf8, x)
         _v2 = FFI::MemoryPointer.new(:pointer).write_pointer nil
         _v3 = Regress::Lib.regress_test_obj_new_from_file _v1, _v2
@@ -80,7 +80,7 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def self.gvalue_in value
+      def self.gvalue_in(value)
         _v1 = GObject::Value.from(value)
         GIMarshallingTests::Lib.gi_marshalling_tests_gvalue_in _v1
       end
@@ -95,11 +95,11 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def self.test_array_int_null_in arr
-        _v1 = GirFFI::SizedArray.from(:gint32, -1, arr)
+      def self.test_array_int_null_in(arr)
         len = arr.nil? ? 0 : arr.length
-        _v2 = len
-        Regress::Lib.regress_test_array_int_null_in _v1, _v2
+        _v1 = len
+        _v2 = GirFFI::SizedArray.from(:gint32, -1, arr)
+        Regress::Lib.regress_test_array_int_null_in _v2, _v1
       end
     CODE
 
@@ -112,12 +112,12 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def self.test_array_int_null_out 
-        _v1 = GirFFI::InOutPointer.for [:pointer, :c]
-        _v2 = GirFFI::InOutPointer.for :gint32
-        Regress::Lib.regress_test_array_int_null_out _v1, _v2
-        _v3 = _v2.to_value
-        _v4 = GirFFI::SizedArray.wrap(:gint32, _v3, _v1.to_value)
+      def self.test_array_int_null_out
+        _v1 = GirFFI::InOutPointer.for :gint32
+        _v2 = GirFFI::InOutPointer.for [:pointer, :c]
+        Regress::Lib.regress_test_array_int_null_out _v2, _v1
+        _v3 = _v1.to_value
+        _v4 = GirFFI::SizedArray.wrap(:gint32, _v3, _v2.to_value)
         return _v4
       end
     CODE
@@ -131,15 +131,15 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def method_array_inout ints
-        _v1 = GirFFI::InOutPointer.for [:pointer, :c]
-        _v1.set_value GirFFI::SizedArray.from(:gint32, -1, ints)
+      def method_array_inout(ints)
         length = ints.nil? ? 0 : ints.length
-        _v2 = GirFFI::InOutPointer.for :gint32
-        _v2.set_value length
-        GIMarshallingTests::Lib.gi_marshalling_tests_object_method_array_inout self, _v1, _v2
-        _v3 = _v2.to_value
-        _v4 = GirFFI::SizedArray.wrap(:gint32, _v3, _v1.to_value)
+        _v1 = GirFFI::InOutPointer.for :gint32
+        _v1.set_value length
+        _v2 = GirFFI::InOutPointer.for [:pointer, :c]
+        _v2.set_value GirFFI::SizedArray.from(:gint32, -1, ints)
+        GIMarshallingTests::Lib.gi_marshalling_tests_object_method_array_inout self, _v2, _v1
+        _v3 = _v1.to_value
+        _v4 = GirFFI::SizedArray.wrap(:gint32, _v3, _v2.to_value)
         return _v4
       end
     CODE
@@ -153,7 +153,7 @@ describe GirFFI::Builders::FunctionBuilder do
     code = fbuilder.generate
 
     expected = <<-CODE
-      def instance_method 
+      def instance_method
         _v1 = Regress::Lib.regress_test_obj_instance_method self
         return _v1
       end
@@ -171,7 +171,7 @@ describe GirFFI::Builders::FunctionBuilder do
       it "builds a correct definition" do
         size_type = ":guint#{FFI.type_size(:size_t) * 8}"
         code.must_equal <<-CODE.reset_indentation
-          def get_strv 
+          def get_strv
             _v1 = GirFFI::InOutPointer.for #{size_type}
             _v2 = GLib::Lib.g_variant_get_strv self, _v1
             _v3 = GLib::Strv.wrap(_v2)
@@ -187,7 +187,7 @@ describe GirFFI::Builders::FunctionBuilder do
       it "builds a correct definition" do
         skip unless function_info
         code.must_equal <<-CODE.reset_indentation
-          def self.has_parameter_named_attrs foo, attributes
+          def self.has_parameter_named_attrs(foo, attributes)
             _v1 = foo
             GirFFI::ArgHelper.check_fixed_array_size 32, attributes, \"attributes\"
             _v2 = GirFFI::SizedArray.from([:pointer, :guint32], 32, attributes)
@@ -206,7 +206,7 @@ describe GirFFI::Builders::FunctionBuilder do
       it "builds a correct definition" do
         skip unless function_info
         code.must_equal <<-CODE.reset_indentation
-          def method_int8_arg_and_out_callee arg
+          def method_int8_arg_and_out_callee(arg)
             _v1 = arg
             _v2 = GirFFI::InOutPointer.for [:pointer, :gint8]
             GIMarshallingTests::Lib.gi_marshalling_tests_object_method_int8_arg_and_out_callee self, _v1, _v2
